# AUTO GENERATED ON 2023-11-13 AT 18:13:22
# DO NOT EDIT BY HAND!
#
# To regenerate file, run
#
#     python dev/generate-tests.py
#

# fmt: off

import cupy
import pytest

import awkward as ak
import awkward._connect.cuda as ak_cu
from awkward._backends.cupy import CupyBackend

cupy_backend = CupyBackend.instance()

def test_cuda_awkward_UnionArray8_32_validity_1():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_2():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_3():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_4():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_5():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_6():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_7():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_8():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_9():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_10():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_11():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_12():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_13():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_14():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_15():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_16():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_17():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_18():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_19():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_20():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_21():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_22():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_23():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_24():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_25():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_26():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_27():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_28():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_29():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_30():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_31():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_32():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_33():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_34():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_35():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_36():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_37():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_38():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_39():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_40():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_41():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_42():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_43():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_44():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_45():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_46():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_47():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_48():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_49():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_50():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 2
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_51():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_52():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_53():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_54():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_55():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_56():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_57():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_58():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_59():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_60():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_61():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_62():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_63():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_64():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_65():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_66():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_67():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_68():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_69():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_70():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_71():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_72():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_73():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_74():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_75():
    tags = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_76():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_77():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_78():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_79():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_80():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_81():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_82():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_83():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_84():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_85():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_86():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_87():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_88():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_89():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_90():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_91():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_92():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_93():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_94():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_95():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_96():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_97():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_98():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_99():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_100():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 3
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_101():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_102():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_103():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_104():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_105():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_106():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_107():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_108():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_109():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_110():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_111():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_112():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_113():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_114():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_115():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_116():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_117():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_118():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_119():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_120():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]

def test_cuda_awkward_UnionArray8_32_validity_121():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_122():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 3, 3, 4, 5, 5, 5, 5, 5, 6, 7, 8, 10, 11], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_123():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([2, 1, 0, 1, 2, 0, 1, 2, 2, 2, 1, 2, 1, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_124():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([1, 0, 2, 3, 1, 2, 0, 0, 1, 1, 2, 3, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]
    funcC(tags, index, length, numcontents, lencontents)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")

def test_cuda_awkward_UnionArray8_32_validity_125():
    tags = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int8)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int32)
    length = 3
    numcontents = 10
    lencontents = cupy.array([0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    funcC = cupy_backend['awkward_UnionArray_validity', cupy.int8, cupy.int32, cupy.int64]




# AUTO GENERATED ON 2023-11-13 AT 18:13:22
# DO NOT EDIT BY HAND!
#
# To regenerate file, run
#
#     python dev/generate-tests.py
#

# fmt: off

import cupy
import pytest

import awkward as ak
import awkward._connect.cuda as ak_cu
from awkward._backends.cupy import CupyBackend

cupy_backend = CupyBackend.instance()

def test_cuda_awkward_missing_repeat_64_1():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 3
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 0, 0, 4, 3, 3, 7, 6, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_2():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 0, 0, 3, 2, 2, 5, 4, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_3():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 1
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 0, 0, 2, 1, 1, 3, 2, 2]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_4():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 0, 0, 3, 2, 2, 5, 4, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_5():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 0
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 0, 0, 1, 0, 0, 1, 0, 0]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_6():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 3
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 2, 2, 4, 5, 5, 7, 8, 8]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_7():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 2, 2, 3, 4, 4, 5, 6, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_8():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 1
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 2, 2, 2, 3, 3, 3, 4, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_9():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 2, 2, 3, 4, 4, 5, 6, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_10():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 2, 2, 3, 0, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 0
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 2, 2, 1, 2, 2, 1, 2, 2]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_11():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 3
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 3, 0, 4, 6, 3, 7, 9, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_12():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 3, 0, 3, 5, 2, 5, 7, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_13():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 1
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 3, 0, 2, 4, 1, 3, 5, 2]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_14():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 3, 0, 3, 5, 2, 5, 7, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_15():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 3, 0, 3, 5, 2, 0, 2, 1, 1], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 0
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 3, 0, 1, 3, 0, 1, 3, 0]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_16():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 3
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 4, 2, 4, 7, 5, 7, 10, 8]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_17():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 4, 2, 3, 6, 4, 5, 8, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_18():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 1
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 4, 2, 2, 5, 3, 3, 6, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_19():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 4, 2, 3, 6, 4, 5, 8, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_20():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([1, 4, 2, 3, 1, 2, 3, 1, 4, 3, 2, 1, 3, 2, 4, 5, 1, 2, 3, 4, 5], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 0
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [1, 4, 2, 1, 4, 2, 1, 4, 2]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_21():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 3
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [0, 0, 0, 3, 3, 3, 6, 6, 6]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_22():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [0, 0, 0, 2, 2, 2, 4, 4, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_23():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 1
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [0, 0, 0, 1, 1, 1, 2, 2, 2]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_24():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 2
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [0, 0, 0, 2, 2, 2, 4, 4, 4]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))

def test_cuda_awkward_missing_repeat_64_25():
    outindex = cupy.array([123, 123, 123, 123, 123, 123, 123, 123, 123], dtype=cupy.int64)
    index = cupy.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=cupy.int64)
    indexlength = 3
    repetitions = 3
    regularsize = 0
    funcC = cupy_backend['awkward_missing_repeat', cupy.int64, cupy.int64]
    funcC(outindex, index, indexlength, repetitions, regularsize)

    try:
        ak_cu.synchronize_cuda()
    except:
        pytest.fail("This test case shouldn't have raised an error")
    pytest_outindex = [0, 0, 0, 0, 0, 0, 0, 0, 0]
    assert cupy.array_equal(outindex[:len(pytest_outindex)], cupy.array(pytest_outindex))




# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

import pytest

import awkward as ak

pytest.importorskip("jax")

ak.jax.register_and_check()


def test():
    ak.nan_to_num(
        ak.Array([1.1, 2.2, 3.3], backend="jax"),
        nan=ak.Array([1.1, 2.2, 3.3], backend="jax"),
    )



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

from collections.abc import Mapping

from awkward._behavior import find_array_typestr
from awkward._parameters import (
    parameters_are_equal,
    parameters_union,
    type_parameters_equal,
)
from awkward._typing import Any, JSONMapping, final
from awkward._util import UNSET, Sentinel
from awkward.types.listtype import ListType
from awkward.types.regulartype import RegularType
from awkward.types.type import Type
from awkward.types.uniontype import UnionType


@final
class OptionType(Type):
    def copy(
        self,
        *,
        content: Type | Sentinel = UNSET,
        parameters: JSONMapping | Sentinel | None = UNSET,
    ) -> OptionType:
        return OptionType(
            self._content if content is UNSET else content,  # type: ignore[arg-type]
            parameters=self._parameters if parameters is UNSET else parameters,  # type: ignore[arg-type]
        )

    def __init__(self, content: Type, *, parameters: JSONMapping | None = None):
        if not isinstance(content, Type):
            raise TypeError(
                "{} 'content' must be a Type subclass, not {}".format(
                    type(self).__name__, repr(content)
                )
            )
        if parameters is not None and not isinstance(parameters, Mapping):
            raise TypeError(
                "{} 'parameters' must be of type Mapping or None, not {}".format(
                    type(self).__name__, repr(parameters)
                )
            )
        self._content: Type = content
        self._parameters: JSONMapping | None = parameters

    @property
    def content(self) -> Type:
        return self._content

    def _str(self, indent: str, compact: bool, behavior: Mapping | None) -> list[str]:
        typestr = find_array_typestr(behavior, self._parameters)

        head = []
        tail = []
        if typestr is not None:
            content_out = [typestr]

        else:
            content_out = self._content._str(indent, compact, behavior)
            params = self._str_parameters()
            if params is None:
                if isinstance(
                    self._content, (RegularType, ListType)
                ) and self._content.parameter("__array__") not in (
                    "string",
                    "bytestring",
                    "char",
                    "byte",
                ):
                    head = ["option["]
                    tail = ["]"]
                else:
                    head = ["?"]

            else:
                head = ["option["]
                tail = [f", {params}]"]

        return [
            *head,
            self._str_categorical_begin(),
            *content_out,
            self._str_categorical_end(),
            *tail,
        ]

    def __repr__(self) -> str:
        args = [repr(self._content), *self._repr_args()]
        return "{}({})".format(type(self).__name__, ", ".join(args))

    def simplify_option_union(self) -> Type:
        if isinstance(self._content, UnionType):
            contents = []
            for content in self._content.contents:
                if isinstance(content, OptionType):
                    contents.append(
                        OptionType(
                            content.content,
                            parameters=parameters_union(
                                self._parameters, content._parameters
                            ),
                        )
                    )

                else:
                    contents.append(OptionType(content, parameters=self._parameters))

            return UnionType(contents, parameters=self._content.parameters)

        else:
            return self

    def _is_equal_to(self, other: Any, all_parameters: bool) -> bool:
        compare_parameters = (
            parameters_are_equal if all_parameters else type_parameters_equal
        )
        return (
            isinstance(other, type(self))
            and compare_parameters(self._parameters, other._parameters)
            and self._content._is_equal_to(
                other._content, all_parameters=all_parameters
            )
        )



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

import awkward as ak
from awkward._dispatch import high_level_function
from awkward._layout import HighLevelContext

__all__ = ("starts_with",)


@high_level_function(module="ak.str")
def starts_with(
    array, pattern, *, ignore_case=False, highlevel=True, behavior=None, attrs=None
):
    """
    Args:
        array: Array-like data (anything #ak.to_layout recognizes).
        pattern (str or bytes): Substring pattern to test against the start
            of each string in `array`.
        ignore_case (bool): If True, perform a case-insensitive match;
            otherwise, the match is case-sensitive.
        highlevel (bool): If True, return an #ak.Array; otherwise, return
            a low-level #ak.contents.Content subclass.
        behavior (None or dict): Custom #ak.behavior for the output array, if
            high-level.
        attrs (None or dict): Custom attributes for the output array, if
            high-level.

    Returns True for every string in `array` if it starts with the given literal
    suffix `pattern`. Depending upon the value of `ignore_case`, the matching
    function will be case-insensitive.

    Note: this function does not raise an error if the `array` does not
    contain any string or bytestring data.

    Requires the pyarrow library and calls
    [pyarrow.compute.starts_with](https://arrow.apache.org/docs/python/generated/pyarrow.compute.starts_with.html).
    """
    # Dispatch
    yield (array,)

    # Implementation
    return _impl(array, pattern, ignore_case, highlevel, behavior, attrs)


def _impl(array, pattern, ignore_case, highlevel, behavior, attrs):
    from awkward._connect.pyarrow import import_pyarrow_compute

    pc = import_pyarrow_compute("ak.str.starts_with")

    with HighLevelContext(behavior=behavior, attrs=attrs) as ctx:
        layout = ctx.unwrap(
            array,
            allow_record=False,
            allow_unknown=False,
            primitive_policy="error",
            string_policy="as-characters",
        )
    apply = ak.operations.str._get_ufunc_action(
        pc.starts_with,
        pc.starts_with,
        bytestring_to_string=False,
        ignore_case=ignore_case,
        pattern=pattern,
    )
    out = ak._do.recursively_apply(layout, apply)
    return ctx.wrap(out, highlevel=highlevel)



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

from awkward.forms import (
    BitMaskedForm,
    ByteMaskedForm,
    EmptyForm,
    Form,
    IndexedForm,
    IndexedOptionForm,
    ListForm,
    ListOffsetForm,
    NumpyForm,
    RecordForm,
    RegularForm,
    UnionForm,
    UnmaskedForm,
)



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

from collections import ChainMap
from collections.abc import Callable, Mapping

import awkward as ak
from awkward._nplikes import ufuncs
from awkward._typing import TYPE_CHECKING, Any

if TYPE_CHECKING:
    from awkward._nplikes.numpy_like import UfuncLike
    from awkward._reducers import Reducer
    from awkward.contents.content import Content
    from awkward.highlevel import Array
    from awkward.highlevel import Record as HighLevelRecord
    from awkward.record import Record


def overlay_behavior(behavior: Mapping | None) -> Mapping:
    """
    Args:
        behavior: behavior dictionary, or None

    Return a ChainMap object that overlays the given behavior
    on top of the global #ak.behavior
    """
    if behavior is None:
        return ak.behavior
    else:
        return ChainMap(behavior, ak.behavior)  # type: ignore[arg-type]


def get_array_class(layout: Content, behavior: Mapping | None) -> type[Array]:
    from awkward.highlevel import Array

    behavior = overlay_behavior(behavior)
    list_name = layout.parameter("__list__")
    if isinstance(list_name, str):
        cls = behavior.get(list_name)
        if isinstance(cls, type) and issubclass(cls, Array):
            return cls
    deep_list_record_name = layout.purelist_parameters("__record__", "__list__")
    if isinstance(deep_list_record_name, str):
        cls = behavior.get(("*", deep_list_record_name))
        if isinstance(cls, type) and issubclass(cls, Array):
            return cls
    return Array


def get_record_class(layout: Record, behavior: Mapping | None) -> type[HighLevelRecord]:
    from awkward.highlevel import Record

    behavior = overlay_behavior(behavior)
    rec = layout.parameter("__record__")
    if isinstance(rec, str):
        cls = behavior.get(rec)
        if isinstance(cls, type) and issubclass(cls, Record):
            return cls
    return Record


def find_record_reducer(
    reducer: Reducer, layout: Record, behavior: Mapping | None
) -> Callable[[Array, bool], Any] | None:
    behavior = overlay_behavior(behavior)
    rec = layout.parameter("__record__")
    if isinstance(rec, str):
        return behavior.get((reducer.highlevel_function(), rec))
    else:
        return None


def find_custom_cast(
    obj: Any, behavior: Mapping | None
) -> Callable[[Any], Content | Record] | None:
    behavior = overlay_behavior(behavior)
    for cls in type(obj).__mro__:
        fcn = behavior.get(("__cast__", cls))
        if fcn is not None:
            return fcn
    return None


def find_ufunc_generic(
    ufunc: UfuncLike, layout: Content, behavior: Mapping | None
) -> Callable[[UfuncLike, str, list, dict], Any] | None:
    behavior = overlay_behavior(behavior)
    custom = layout.parameter("__list__")
    if custom is None:
        custom = layout.parameter("__record__")
    if isinstance(custom, str):
        fcn = behavior.get((ufunc, custom))
        if fcn is None:
            fcn = behavior.get((ufuncs.ufunc, custom))
        return fcn
    else:
        return None


def find_ufunc(behavior: Mapping | None, signature: tuple) -> UfuncLike | None:
    if all(s is not None for s in signature):
        behavior = overlay_behavior(behavior)

        # Special case all strings or hashable types.
        if all(isinstance(x, str) for x in signature):
            return behavior.get(signature)
        else:
            for key, custom in behavior.items():
                if (
                    isinstance(key, tuple)
                    and len(key) == len(signature)
                    and key[0] == signature[0]
                    and all(
                        k == s
                        or (
                            isinstance(k, type)
                            and isinstance(s, type)
                            and issubclass(s, k)
                        )
                        for k, s in zip(key[1:], signature[1:])
                    )
                ):
                    return custom
    return None


def find_record_typestr(
    behavior: None | Mapping,
    parameters: None | Mapping[str, Any],
    default: str | None = None,
) -> str | None:
    if parameters is None:
        return default
    behavior = overlay_behavior(behavior)
    return behavior.get(("__typestr__", parameters.get("__record__")), default)


def find_array_typestr(
    behavior: None | Mapping,
    parameters: None | Mapping[str, Any],
    default: str | None = None,
) -> str | None:
    if parameters is None:
        return default
    behavior = overlay_behavior(behavior)
    return behavior.get(("__typestr__", parameters.get("__list__")), default)


def behavior_of_obj(obj: Any, behavior: Mapping | None = None) -> Mapping | None:
    from awkward.highlevel import Array, ArrayBuilder, Record

    if behavior is not None:
        return behavior
    elif isinstance(obj, (Array, Record, ArrayBuilder)):
        return obj._behavior
    else:
        return None


def behavior_of(*arrays: Any, behavior: Mapping | None = None) -> Mapping | None:
    if behavior is not None:
        # An explicit 'behavior' always wins.
        return behavior

    copied = False
    for x in arrays[::-1]:
        x_behavior = behavior_of_obj(x)
        # Don't merge shared behaviors!
        if x_behavior is None or behavior is x_behavior:
            pass
        elif behavior is None:
            behavior = x_behavior
        elif not copied:
            behavior = dict(behavior)
            behavior.update(x_behavior)
            copied = True
        else:
            assert isinstance(behavior, dict)
            behavior.update(x_behavior)
    return behavior



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

import numpy as np
import pytest  # noqa: F401

import awkward as ak


def test():
    array = ak.Array([1, 2, 3, 4])
    first = ak.firsts(array, axis=0)
    assert isinstance(first, np.int64) and first == 1


def test_non_scalar():
    array = ak.Array([[1, 2, 3], [4]])
    first = ak.firsts(array, axis=0)
    assert first.to_list() == [1, 2, 3]



from __future__ import annotations

import numpy as np

import awkward as ak


def test_unknown_scalar():
    scalar = ak.typetracer.create_unknown_scalar(np.int64)
    assert scalar.dtype == np.dtype(np.int64)
    assert scalar.shape == ()
    assert ak.typetracer.is_unknown_scalar(scalar)

    scalar = ak.typetracer.create_unknown_scalar("int64")
    assert scalar.dtype == np.dtype(np.int64)
    assert scalar.shape == ()
    assert ak.typetracer.is_unknown_scalar(scalar)



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

import awkward as ak
from awkward._dispatch import high_level_function
from awkward._layout import HighLevelContext

__all__ = ("split_pattern_regex",)


@high_level_function(module="ak.str")
def split_pattern_regex(
    array,
    pattern,
    *,
    max_splits=None,
    reverse=False,
    highlevel=True,
    behavior=None,
    attrs=None,
):
    """
    Args:
        array: Array-like data (anything #ak.to_layout recognizes).
        pattern (str or bytes): Regular expression of characters/bytes to
            split on.
        max_splits (None or int): Maximum number of splits for each input
            value. If None, unlimited.
        reverse (bool): If True, start splitting from the end of each input
            value; otherwise, start splitting from the beginning of each
            value. This flag only has an effect if `max_splits` is not None.
        highlevel (bool): If True, return an #ak.Array; otherwise, return
            a low-level #ak.contents.Content subclass.
        behavior (None or dict): Custom #ak.behavior for the output array, if
            high-level.
        attrs (None or dict): Custom attributes for the output array, if
            high-level.

    Splits any string or bytestring-valued data into a list of substrings
    according to the given regular expression.

    Note: this function does not raise an error if the `array` does not
    contain any string or bytestring data.

    Requires the pyarrow library and calls
    [pyarrow.compute.split_pattern](https://arrow.apache.org/docs/python/generated/pyarrow.compute.split_pattern.html).

    See also: #ak.str.split_whitespace, #ak.str.split_pattern.
    """
    # Dispatch
    yield (array,)

    # Implementation
    return _impl(array, pattern, max_splits, reverse, highlevel, behavior, attrs)


def _impl(array, pattern, max_splits, reverse, highlevel, behavior, attrs):
    from awkward._connect.pyarrow import import_pyarrow_compute

    pc = import_pyarrow_compute("ak.str.split_pattern_regex")

    with HighLevelContext(behavior=behavior, attrs=attrs) as ctx:
        layout = ctx.unwrap(
            array,
            allow_record=False,
            allow_unknown=False,
            primitive_policy="error",
            string_policy="as-characters",
        )

    if reverse:
        raise ValueError("Cannot split in reverse with regex")

    action = ak.operations.str._get_split_action(
        pc.split_pattern_regex,
        pc.split_pattern_regex,
        pattern=pattern,
        max_splits=max_splits,
        reverse=reverse,
        bytestring_to_string=False,
    )
    out = ak._do.recursively_apply(layout, action)

    return ctx.wrap(out, highlevel=highlevel)



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

import math

import awkward as ak
from awkward._backends.dispatch import regularize_backend
from awkward._dispatch import high_level_function
from awkward._layout import wrap_layout
from awkward._nplikes.array_like import ArrayLike
from awkward._nplikes.numpy import Numpy
from awkward._nplikes.numpy_like import NumpyLike, NumpyMetadata
from awkward._nplikes.placeholder import PlaceholderArray
from awkward._nplikes.shape import ShapeItem, unknown_length
from awkward._regularize import is_integer
from awkward.forms.form import index_to_dtype, regularize_buffer_key

__all__ = ("from_buffers",)

np = NumpyMetadata.instance()
numpy = Numpy.instance()


@high_level_function()
def from_buffers(
    form,
    length,
    container,
    buffer_key="{form_key}-{attribute}",
    *,
    backend="cpu",
    byteorder="<",
    allow_noncanonical_form=False,
    highlevel=True,
    behavior=None,
    attrs=None,
):
    """
    Args:
        form (#ak.forms.Form or str/dict equivalent): The form of the Awkward
            Array to reconstitute from named buffers.
        length (int): Length of the array. (The output of this function is always
            single-partition.)
        container (Mapping, such as dict): The str \u2192 Python buffers that
            represent the decomposed Awkward Array. This `container` is only
            assumed to have a `__getitem__` method that accepts strings as keys.
        buffer_key (str or callable): Python format string containing
            `"{form_key}"` and/or `"{attribute}"` or a function that takes these
            as keyword arguments and returns a string to use as a key for a buffer
            in the `container`.
        backend (str): Library to use to generate values that are
            put into the new array. The default, cpu, makes NumPy
            arrays, which are in main memory (e.g. not GPU). If all the values in
            `container` have the same `backend` as this, they won't be copied.
        byteorder (`"<"`, `">"`): Endianness of buffers read from `container`.
            If the byteorder does not match the current system byteorder, the
            arrays will be copied.
        allow_noncanonical_form (bool): If True, non-canonical forms will be
            simplified to produce arrays with canonical layouts; otherwise,
            an exception will be thrown for such forms.
        highlevel (bool): If True, return an #ak.Array; otherwise, return
            a low-level #ak.contents.Content subclass.
        behavior (None or dict): Custom #ak.behavior for the output array, if
            high-level.
        attrs (None or dict): Custom attributes for the output array, if
            high-level.

    Reconstitutes an Awkward Array from a Form, length, and a collection of memory
    buffers, so that data can be losslessly read from file formats and storage
    devices that only map names to binary blobs (such as a filesystem directory).

    The first three arguments of this function are the return values of
    #ak.to_buffers, so a full round-trip is

        >>> reconstituted = ak.from_buffers(*ak.to_buffers(original))

    The `container` argument lets you specify your own Mapping, which might be
    an interface to some storage format or device (e.g. h5py). It's okay if
    the `container` dropped NumPy's `dtype` and `shape` information, leaving
    raw bytes, since `dtype` and `shape` can be reconstituted from the
    #ak.forms.NumpyForm.
    If the values of `container` are recognised as arrays by the given backend,
    a view over their existing data will be used, where possible.

    The `buffer_key` should be the same as the one used in #ak.to_buffers.

    When `allow_noncanonical_form` is set to True, this function readily accepts
    non-simplified forms, i.e. forms which will be simplified by Awkward Array
    into "canonical" representations, e.g. `option[option[...]]` → `option[...]`.
    Such forms can be produced by the low-level ArrayBuilder `snapshot()` method.
    Given that Awkward Arrays must have canonical layouts, it follows that
    invoking this function with `allow_noncanonical_form` may produce arrays
    whose forms differ to the input form.

    In order for a non-simplified form to be considered valid, it should be one
    that the #ak.contents.Content layout classes could produce iff. the
    simplification rules were removed.


    See #ak.to_buffers for examples.
    """
    return _impl(
        form,
        length,
        container,
        buffer_key,
        backend,
        byteorder,
        highlevel,
        behavior,
        attrs,
        allow_noncanonical_form,
    )


def _impl(
    form,
    length,
    container,
    buffer_key,
    backend,
    byteorder,
    highlevel,
    behavior,
    attrs,
    simplify,
):
    backend = regularize_backend(backend)

    if isinstance(form, str):
        if ak.types.numpytype.is_primitive(form):
            form = ak.forms.NumpyForm(form)
        else:
            form = ak.forms.from_json(form)
    elif isinstance(form, dict):
        form = ak.forms.from_dict(form)

    if not (is_integer(length) and length >= 0):
        raise TypeError("'length' argument must be a non-negative integer")

    if not isinstance(form, ak.forms.Form):
        raise TypeError(
            "'form' argument must be a Form or its Python dict/JSON string representation"
        )

    getkey = regularize_buffer_key(buffer_key)

    out = _reconstitute(form, length, container, getkey, backend, byteorder, simplify)

    return wrap_layout(out, highlevel=highlevel, attrs=attrs, behavior=behavior)


def _from_buffer(
    nplike: NumpyLike, buffer, dtype: np.dtype, count: ShapeItem, byteorder: str
) -> ArrayLike:
    # Unknown-length information implies that we didn't load shape-buffers (offsets, etc)
    # for the parent of this node. Thus, this node and its children *must* only
    # contain placeholders
    if count is unknown_length:
        # We may actually have a known buffer here, but as we do not know the length,
        # we cannot safely trim it. Thus, introduce a placeholder anyway
        return PlaceholderArray(nplike, (unknown_length,), dtype)
    # Known-length information implies that we should have known-length buffers here
    # We could choose to make this an error, and have the caller re-implement some
    # of #ak.from_buffers, or we can just introduce the known lengths where possible
    elif isinstance(buffer, PlaceholderArray) and buffer.size is unknown_length:
        return PlaceholderArray(nplike, (count,), dtype)
    elif isinstance(buffer, PlaceholderArray) or nplike.is_own_array(buffer):
        # Require 1D buffers
        array = nplike.reshape(buffer.view(dtype), shape=(-1,), copy=False)

        if array.size < count:
            raise TypeError(
                f"size of array ({array.size}) is less than size of form ({count})"
            )

        return array[:count]
    else:
        array = nplike.frombuffer(buffer, dtype=dtype, count=count)
        if byteorder != ak._util.native_byteorder:
            return array.byteswap(inplace=False)
        else:
            return array


def _reconstitute(form, length, container, getkey, backend, byteorder, simplify):
    if isinstance(form, ak.forms.EmptyForm):
        if length != 0:
            raise ValueError(f"EmptyForm node, but the expected length is {length}")
        return ak.contents.EmptyArray()

    elif isinstance(form, ak.forms.NumpyForm):
        dtype = ak.types.numpytype.primitive_to_dtype(form.primitive)
        raw_array = container[getkey(form, "data")]
        real_length = length * math.prod(form.inner_shape)
        data = _from_buffer(
            backend.nplike,
            raw_array,
            dtype=dtype,
            count=real_length,
            byteorder=byteorder,
        )
        if form.inner_shape != ():
            data = backend.nplike.reshape(data, (length, *form.inner_shape))

        return ak.contents.NumpyArray(
            data, parameters=form._parameters, backend=backend
        )

    elif isinstance(form, ak.forms.UnmaskedForm):
        content = _reconstitute(
            form.content, length, container, getkey, backend, byteorder, simplify
        )
        if simplify:
            make = ak.contents.UnmaskedArray.simplified
        else:
            make = ak.contents.UnmaskedArray
        return make(content, parameters=form._parameters)

    elif isinstance(form, ak.forms.BitMaskedForm):
        raw_array = container[getkey(form, "mask")]
        if length is unknown_length:
            next_length = unknown_length
        else:
            next_length = int(math.ceil(length / 8.0))
        mask = _from_buffer(
            backend.index_nplike,
            raw_array,
            dtype=index_to_dtype[form.mask],
            count=next_length,
            byteorder=byteorder,
        )
        content = _reconstitute(
            form.content, length, container, getkey, backend, byteorder, simplify
        )
        if simplify:
            make = ak.contents.BitMaskedArray.simplified
        else:
            make = ak.contents.BitMaskedArray
        return make(
            ak.index.Index(mask),
            content,
            form.valid_when,
            length,
            form.lsb_order,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.ByteMaskedForm):
        raw_array = container[getkey(form, "mask")]
        mask = _from_buffer(
            backend.index_nplike,
            raw_array,
            dtype=index_to_dtype[form.mask],
            count=length,
            byteorder=byteorder,
        )
        content = _reconstitute(
            form.content, length, container, getkey, backend, byteorder, simplify
        )
        if simplify:
            make = ak.contents.ByteMaskedArray.simplified
        else:
            make = ak.contents.ByteMaskedArray
        return make(
            ak.index.Index(mask),
            content,
            form.valid_when,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.IndexedOptionForm):
        raw_array = container[getkey(form, "index")]
        index = _from_buffer(
            backend.index_nplike,
            raw_array,
            dtype=index_to_dtype[form.index],
            count=length,
            byteorder=byteorder,
        )
        if isinstance(index, PlaceholderArray):
            next_length = unknown_length
        else:
            next_length = (
                0 if len(index) == 0 else max(0, backend.index_nplike.max(index) + 1)
            )
        content = _reconstitute(
            form.content, next_length, container, getkey, backend, byteorder, simplify
        )
        if simplify:
            make = ak.contents.IndexedOptionArray.simplified
        else:
            make = ak.contents.IndexedOptionArray
        return make(
            ak.index.Index(index),
            content,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.IndexedForm):
        raw_array = container[getkey(form, "index")]
        index = _from_buffer(
            backend.index_nplike,
            raw_array,
            dtype=index_to_dtype[form.index],
            count=length,
            byteorder=byteorder,
        )
        if isinstance(index, PlaceholderArray):
            next_length = unknown_length
        else:
            next_length = (
                0
                if len(index) == 0
                else backend.index_nplike.index_as_shape_item(
                    backend.index_nplike.max(index) + 1
                )
            )
        content = _reconstitute(
            form.content, next_length, container, getkey, backend, byteorder, simplify
        )
        if simplify:
            make = ak.contents.IndexedArray.simplified
        else:
            make = ak.contents.IndexedArray
        return make(
            ak.index.Index(index),
            content,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.ListForm):
        raw_array1 = container[getkey(form, "starts")]
        raw_array2 = container[getkey(form, "stops")]
        starts = _from_buffer(
            backend.index_nplike,
            raw_array1,
            dtype=index_to_dtype[form.starts],
            count=length,
            byteorder=byteorder,
        )
        stops = _from_buffer(
            backend.index_nplike,
            raw_array2,
            dtype=index_to_dtype[form.stops],
            count=length,
            byteorder=byteorder,
        )
        if isinstance(stops, PlaceholderArray):
            next_length = unknown_length
        else:
            reduced_stops = stops[starts != stops]
            next_length = (
                0 if len(starts) == 0 else backend.index_nplike.max(reduced_stops)
            )
        content = _reconstitute(
            form.content, next_length, container, getkey, backend, byteorder, simplify
        )
        return ak.contents.ListArray(
            ak.index.Index(starts),
            ak.index.Index(stops),
            content,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.ListOffsetForm):
        raw_array = container[getkey(form, "offsets")]
        offsets = _from_buffer(
            backend.index_nplike,
            raw_array,
            dtype=index_to_dtype[form.offsets],
            count=length + 1,
            byteorder=byteorder,
        )

        if isinstance(offsets, PlaceholderArray):
            next_length = unknown_length
        else:
            next_length = 0 if len(offsets) == 1 else offsets[-1]
        content = _reconstitute(
            form.content, next_length, container, getkey, backend, byteorder, simplify
        )
        return ak.contents.ListOffsetArray(
            ak.index.Index(offsets),
            content,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.RegularForm):
        next_length = length * form.size
        content = _reconstitute(
            form.content, next_length, container, getkey, backend, byteorder, simplify
        )
        return ak.contents.RegularArray(
            content,
            form.size,
            length,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.RecordForm):
        contents = [
            _reconstitute(
                content, length, container, getkey, backend, byteorder, simplify
            )
            for content in form.contents
        ]
        return ak.contents.RecordArray(
            contents,
            None if form.is_tuple else form.fields,
            length,
            parameters=form._parameters,
        )

    elif isinstance(form, ak.forms.UnionForm):
        raw_array1 = container[getkey(form, "tags")]
        raw_array2 = container[getkey(form, "index")]
        tags = _from_buffer(
            backend.index_nplike,
            raw_array1,
            dtype=index_to_dtype[form.tags],
            count=length,
            byteorder=byteorder,
        )
        index = _from_buffer(
            backend.index_nplike,
            raw_array2,
            dtype=index_to_dtype[form.index],
            count=length,
            byteorder=byteorder,
        )
        if isinstance(index, PlaceholderArray) or isinstance(tags, PlaceholderArray):
            lengths = [unknown_length] * len(form.contents)
        else:
            lengths = []
            for tag in range(len(form.contents)):
                selected_index = index[tags == tag]
                if len(selected_index) == 0:
                    lengths.append(0)
                else:
                    lengths.append(backend.index_nplike.max(selected_index) + 1)
        contents = [
            _reconstitute(
                content, lengths[i], container, getkey, backend, byteorder, simplify
            )
            for i, content in enumerate(form.contents)
        ]
        if simplify:
            make = ak.contents.UnionArray.simplified
        else:
            make = ak.contents.UnionArray
        return make(
            ak.index.Index(tags),
            ak.index.Index(index),
            contents,
            parameters=form._parameters,
        )

    else:
        raise AssertionError("unexpected form node type: " + str(type(form)))



# BSD 3-Clause License; see https://github.com/scikit-hep/awkward/blob/main/LICENSE

from __future__ import annotations

import sys
from collections.abc import Mapping

import awkward as ak
from awkward._typing import Any
from awkward.types.type import Type


class ScalarType:
    def __init__(self, content: Type, behavior: Mapping | None = None):
        if not isinstance(content, ak.types.Type):
            raise TypeError(
                "{} all 'contents' must be Type subclasses, not {}".format(
                    type(self).__name__, repr(content)
                )
            )
        self._content: Type = content
        self._behavior: Mapping | None = behavior

    @property
    def content(self) -> Type:
        return self._content

    @property
    def behavior(self) -> Mapping | None:
        return self._behavior

    def __str__(self) -> str:
        return "".join(self._str("", True))

    def show(self, stream=sys.stdout):
        stream.write("".join([*self._str("", False), "\n"]))

    def _str(self, indent: str, compact: bool) -> list[str]:
        return self._content._str(
            indent,
            compact,
            self._behavior,
        )

    def __repr__(self) -> str:
        return f"{type(self).__name__}({self._content!r}, {self._behavior!r})"

    def is_equal_to(self, other: Any, *, all_parameters: bool = False) -> bool:
        return isinstance(other, type(self)) and self._content.is_equal_to(
            other._content, all_parameters=all_parameters
        )

    __eq__ = is_equal_to
